Implementation of PMM2 algorithm for time series models with various approaches depending on the model structure (AR, MA, ARMA, ARIMA)
.ts_pmm2_fit(
b_init,
innovations_init,
model_info,
m2,
m3,
m4,
max_iter = 50,
tol = 1e-06,
regularize = TRUE,
reg_lambda = 1e-08,
verbose = FALSE
)A list with components:
estimated parameters
logical convergence status
number of iterations performed
final innovations (errors)
initial parameter estimates (AR followed by MA)
initial innovations (errors)
list with model structure information
central moments
maximum number of iterations
convergence tolerance
logical, add small value to diagonal for numerical stability
regularization parameter (if regularize=TRUE)
logical, whether to print progress information